@@ -1,4 +1,4 @@
-/* $Id: pkgin.h,v 1.14.2.1 2011/01/16 12:38:14 imil Exp $ */
+/* $Id: pkgin.h,v 1.32 2011/02/09 13:06:17 imil Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -53,7 +53,8 @@
 #define PKG_ADD PKGTOOLS"/pkg_add"
 
 #define PKG_SUMMARY "pkg_summary"
-#define PKGIN_LOG PKGIN_DB"/pkgin.log"
+#define PKGIN_SQL_LOG PKGIN_DB"/sql.log"
+#define PKGIN_ERR_LOG PKGIN_DB"/err.log"
 #define PKGIN_CACHE PKGIN_DB"/cache"
 #define PKG_EXT ".tgz"
 #define PKGIN_CONF PKG_SYSCONFDIR"/pkgin"
@@ -74,8 +75,12 @@
 #define UPGRADE_ALL 1
 #define UPGRADE_NONE -1
 
+#define DO_INST 1
+#define DONT_INST 0
+
 #define ALNUM "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
 #define DELIMITER '|'
+#define ICON_WAIT "-\\|/"
 
 #define PKG_LLIST_CMD 0
 #define PKG_RLIST_CMD 1
@@ -139,6 +144,7 @@ typedef SLIST_HEAD(, Pkgimpact) Impacthead;
 extern int			yesflag;
 extern int			noflag;
 extern int			force_update;
+extern int			force_reinstall;
 extern char			**pkg_repos;
 extern const char	*pkgin_cache;
 extern char  		lslimit;
@@ -165,7 +171,7 @@ char		*end_expr(Plisthead *, const char *);
 /* actions.c */
 int			check_yesno(void);
 int			pkgin_remove(char **);
-int			pkgin_install(char **);
+int			pkgin_install(char **, uint8_t);
 char		*action_list(char *, char *);
 void		pkgin_upgrade(int);
 /* order.c */
