@@ -1,4 +1,4 @@
-/* $Id: pkgindb.c,v 1.10.2.1 2011/01/16 12:38:14 imil Exp $ */
+/* $Id: pkgindb.c,v 1.24 2011/02/06 17:41:45 imil Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -42,9 +42,17 @@ static const char *pragmaopts[] = {
 	"cache_size = 1000000",
 	"locking_mode = EXCLUSIVE",
 	"empty_result_callbacks = 1",
+	"synchronous = OFF",
+	"journal_mode = MEMORY",
 	NULL
 };
-/*			"synchronous = OFF", */
+
+const char *
+pdb_version(void)
+{
+	return "SQLite "SQLITE_VERSION;
+}
+
 static void
 pdb_err(const char *errmsg)
 {
@@ -63,7 +71,7 @@ pdb_err(const char *errmsg)
  *  ______________________________________
  * | argv[0] | argv[1] | ... | argv[argc] |
  *
- * WARNING: callbacl is called on every line
+ * WARNING: callback is called on every line
  */
 static int
 pkgindb_simple_callback(void *param, int argc, char **argv, char **colname)
@@ -122,10 +130,10 @@ pkgindb_init()
 	char buf[BUFSIZ];
 
 	/*
-	 * Do not exit if PKGIN_LOG is not writable.
+	 * Do not exit if PKGIN_SQL_LOG is not writable.
 	 * Permit users to do list-operations
 	 */
-	fp = fopen(PKGIN_LOG, "w");
+	fp = fopen(PKGIN_SQL_LOG, "w");
 
 	if (sqlite3_open(PDB, &pdb) != SQLITE_OK)
 		pdb_err("Can't open database " PDB);
