@@ -1,4 +1,4 @@
-/* $Id: tools.h,v 1.4.2.1 2011/01/16 12:38:14 imil Exp $ */
+/* $Id: tools.h,v 1.17 2011/01/30 11:19:32 imil Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -36,6 +36,9 @@
 #if HAVE_CONFIG_H
 #include "config.h"
 #endif
+#if HAVE_NBCOMPAT_H
+#include <nbcompat.h>
+#endif
 #if HAVE_STDIO_H
 #include <stdio.h>
 #endif
@@ -54,7 +57,9 @@
 #if HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
-#if HAVE_STRING_H
+#if HAVE_NBCOMPAT_STRING_H /* strsep() */
+#include <nbcompat/string.h>
+#elif HAVE_STRING_H
 #include <string.h>
 #endif
 #if HAVE_SYS_STAT_H
@@ -69,13 +74,23 @@
 #if HAVE_SYS_UTSNAME_H
 #include <sys/utsname.h>
 #endif
-
-#if HAVE_NBCOMPAT_H /* needed for strsep on SunOS < 5.11 */
-#include <nbcompat.h>
-#include <nbcompat/string.h>
+#if defined(HAVE_LIBUTIL_H)
+#include <libutil.h>
+#elif defined(HAVE_UTIL_H)
+#include <util.h>
+#else
+#include <nbcompat/util.h>
 #endif
 
+#ifndef HN_AUTOSCALE
+#include "humanize_number.h"
+#endif
+
+#ifdef LINE_MAX
 #define MAXLEN LINE_MAX
+#else
+#define MAXLEN 2048
+#endif
 #define MIDLEN 256
 #define SMLLEN 32
 #define D_WARN 5
